AsyncRouteGuard<T extends Object> class abstract interface

Asynchronous route-specific guard contract.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canActivate(T route) Future<T?>
Returns null to allow navigation, or a replacement route to redirect.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited