I18nConfig class final

Runtime i18n configuration.

Annotations

Constructors

I18nConfig({required List<String> locales, required String fallbackLocale, List<String> namespaces = const []})
Creates runtime configuration for the supported locales.
const

Properties

fallbackLocale String
Locale used when the active locale does not contain a key.
final
hashCode int
The hash code for this object.
no setterinherited
locales List<String>
Locale codes supported by the application.
final
namespaces List<String>
Optional translation namespaces with one ARB file per locale.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited