RouteGuardChain<T extends Object> class final

Runs route guards in generated declaration order.

Constructors

RouteGuardChain(List<Object> guards)
Creates a guard chain.
const

Properties

guards List<Object>
Guards to run. Generated code guarantees each entry is a supported guard.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canActivate(T route) Future<T?>
Runs sync and async guards in the order generated for the route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited