maxRedirects top-level constant
int
const maxRedirects
Maximum redirect hops before the router reports a debug-cycle assertion.
Implementation
const int maxRedirects = 8;
Maximum redirect hops before the router reports a debug-cycle assertion.
const int maxRedirects = 8;