AsyncState<T> class
sealed
Lifecycle state for generated async ViewModels.
- Implementers
Properties
- data → T?
-
Current visible data, when available.
no setter
- error → Object?
-
Current load error, when available.
no setter
- hasData → bool
-
Whether current visible data is available.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPreviousData → bool
-
Whether previous visible data is available.
no setter
- isLoading → bool
-
Whether a load or refresh is in progress.
no setter
- isRefreshing → bool
-
Whether visible data is being refreshed.
no setter
- previousData → T?
-
Data preserved from the previous successful load, when available.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace for the current load failure, when available.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited