GeneratedRouteInformationParser<T extends Object> class
final
Navigator 2.0 route information parser for generated routes.
- Inheritance
-
- Object
- RouteInformationParser<
T> - GeneratedRouteInformationParser
Constructors
-
GeneratedRouteInformationParser({required RouteParser<
T> parseRoute, required RouteLocation<T> routeLocation}) -
Creates a route information parser.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parseRoute
→ RouteParser<
T> -
URI-to-route parser generated by Dust.
final
-
routeLocation
→ RouteLocation<
T> -
Route-to-location formatter generated by Dust.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseRouteInformation(
RouteInformation routeInformation) → Future< T> -
Converts the given route information into parsed data to pass to a
RouterDelegate.
override
-
parseRouteInformationWithDependencies(
RouteInformation routeInformation, BuildContext context) → Future< T> -
Converts the given route information into parsed data to pass to a
RouterDelegate.
inherited
-
restoreRouteInformation(
T configuration) → RouteInformation -
Restore the route information from the given configuration.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited