RouterController<T extends Object> class
final
Imperative navigation controller exposed through generated extensions.
Properties
- currentRoute → T
-
Top route on the current stack.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stack
→ RouteStack<
T> -
Immutable copy of the current stack.
no setter
Methods
-
go(
T route) → void -
Replaces the whole stack with
route. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<
R> ([R? result]) → bool -
Pops the top route if possible and completes its push future with
result. -
push<
R> (T route) → Future< R?> -
Pushes
routeon top of the current stack. -
replace(
T route) → void -
Replaces the current top route with
route. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of<
T extends Object> (BuildContext context) → RouterController< T> - Returns the nearest typed router controller.