SilentStateObserver class final
No-op observer for tests and production apps that do not want logging.
- Implemented types
Constructors
- SilentStateObserver()
-
Creates a no-op observer.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChanged(
Object viewModel, Object? previous, Object? next) → void -
Called after
viewModelchanges fromprevioustonext.override -
onEffect(
Object viewModel, Object effect) → void -
Called when
viewModelemits a one-shoteffect.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited